@@ -36,7 +36,7 @@ describe 'swift::storage::server' do
         'foo'
       end
 
-      it_raises 'a Puppet::Error', /does not match/
+      it { should raise_error(Puppet::Error) }
     end
 
     ['account', 'object', 'container'].each do |t|
@@ -84,7 +84,7 @@ describe 'swift::storage::server' do
 
           describe "when pipeline is not passed an array" do
             let :params do req_params.merge({:pipeline => 'not an array'}) end
-            it_raises 'a Puppet::Error', /is not an Array/
+            it { should raise_error(Puppet::Error) }
           end
 
           describe "when replicator_concurrency is set" do
@@ -92,6 +92,16 @@ describe 'swift::storage::server' do
             it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/\[#{t}-replicator\]\nconcurrency\s*=\s*42\s*$/m) }
           end
 
+          if t != 'object'
+            describe "when replicator_concurrency and replicator_interval are set" do
+              let :params do req_params.merge(
+                { :replicator_concurrency => 42,
+                  :replicator_interval => 42})
+              end
+              it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/\[#{t}-replicator\]\nconcurrency\s*=\s*42\ninterval\s*=\s*42\s*$/m) }
+            end
+          end
+
           if t != 'account'
             describe "when updater_concurrency is set" do
               let :params do req_params.merge({:updater_concurrency => 73}) end
